@@ -64,8 +64,15 @@ record <- function(.data, cmd){
 }
 
 play <- function(.data, cmds=NULL){
+#  browser()
   for (cmd in cmds){
-    .data <- lazyeval::lazy_eval(cmd, list(.data=.data))
+    env <- parent.frame()
+    expr <- cmd
+    if (rlang::is_quosure(cmd)){
+      env <- rlang::get_env(cmd)
+      expr <- rlang::get_expr(cmd)
+    }
+    .data <- eval(expr, list(.data=.data), enclos = env)
   }
   .data
 }
@@ -74,62 +81,3 @@ play <- function(.data, cmds=NULL){
 as.data.frame.chunkwise <- function(x, row.names = NULL, optional = FALSE, ...){
   as.data.frame(collect(x), row.names = row.names, optional=optional, ...)
 }
-
-# chunked_laf <- function(x, chunk_size = 1e4L){
-#   .completed <- FALSE
-#
-#   reset <- function(){
-#     LaF::begin(x)
-#     .completed <<- FALSE
-#   }
-#
-#   hasNext <- function(){
-#     !.completed
-#   }
-#
-#   nextElem <- function(){
-#     if (.completed){
-#       return(NULL)
-#     }
-#
-#     ch <- LaF::next_block(x, nrows = chunk_size)
-#     N <- nrow(ch)
-#
-#     if ( N < chunk_size){
-#       .completed <<- TRUE
-#     }
-#
-#     if (N == 0){
-#       return(NULL)
-#     }
-#     ch
-#   }
-#
-#   reset()
-#   structure(
-#     list( reset    = reset
-#         , hasNext  = hasNext
-#         , nextElem = nextElem
-#         ),
-#     class="chunked_laf"
-#   )
-# }
-
-### testing
-
-# write.csv(women, "ext-data/women.csv", row.names = FALSE, quote=FALSE)
-#
-# women_chunked <- read_csv_chunkwise("ext-data/women.csv", chunk_size = 5)
-#
-# w <-
-#   women_chunked %>%
-#   mutate(height_m = height * 2.54/100) %>%
-#   filter(height_m < 1.50) %>%
-#   select(weight, height_m)
-#
-# w %>% collect()
-# w
-#
-# w %>% write_csv_chunkwise(file="ext-data/test.csv")
-#
-# inner_join(w, women)
