@@ -12,7 +12,10 @@ describe("print", {
 describe("print groups", {
   it("should print groups chunked info", {
     tbl_iris <- get_tbl_iris() %>% group_by(Species)
-    expect_warning(expect_output(print(tbl_iris), "^Source: chunked text file"))
-    expect_warning(expect_output(print(tbl_iris), "Groups: Species"))
+    suppressWarnings({
+      expect_output(print(tbl_iris), "^Source: chunked text file")
+      expect_output(print(tbl_iris), "Groups: Species")
+    })
+    #expect_warning(print(tbl_iris))
   })
 })
